A Python module for combining *p* values of discrete tests.

* Read the `paper <https://doi.org/10.21105/joss.06096>`_ for a short overview; read the `documentation <https://combine-p-values-discrete.rtfd.io>`_ for more.
* Install with:

  * ``pip install combine-pvalues-discrete``
  * ``pip3 install git+git://github.com/BPSB/combine-p-values-discrete``
  * or similar.

* Install requirements for testing with ``pip install ".[test]"`` (or similar). Run the test with ``pytest`` (or similar) in the source directory. Run ``pytest -m "not slow"`` to exclude some particularly time-consuming tests.
* `Issue Tracker <https://github.com/BPSB/combine-p-values-discrete/issues>`_ – Please use this if you need any help with this module, in particular if you are facing any bugs or require features (in particular support for tests).
* Contributions are welcome. Feel free to discuss them on the issue tracker or just file a pull request.
* Cite the `paper <https://doi.org/10.21105/joss.06096>`_ to give credit or shift blame. If you want to cite specific versions, you can find them on `Zenodo <https://dx.doi.org/10.5281/zenodo.8338798>`_.

.. image:: https://joss.theoj.org/papers/10.21105/joss.06096/status.svg
  :target: https://doi.org/10.21105/joss.06096

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10684537.svg
  :target: https://doi.org/10.5281/zenodo.10684537

